@@ -132,7 +132,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -148,41 +148,41 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_ec2
-import aws_cdk.aws_ecs
-import aws_cdk.aws_events
-import constructs
+import aws_cdk.aws_ec2 as _aws_cdk_aws_ec2_ceddda9d
+import aws_cdk.aws_ecs as _aws_cdk_aws_ecs_ceddda9d
+import aws_cdk.aws_events as _aws_cdk_aws_events_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class FargateToEventbridge(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-fargate-eventbridge.FargateToEventbridge",
 ):
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         public_api: builtins.bool,
-        cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
+        cluster_props: typing.Optional[typing.Union[_aws_cdk_aws_ecs_ceddda9d.ClusterProps, typing.Dict[builtins.str, typing.Any]]] = None,
         container_definition_props: typing.Any = None,
         ecr_image_version: typing.Optional[builtins.str] = None,
         ecr_repository_arn: typing.Optional[builtins.str] = None,
         event_bus_environment_variable_name: typing.Optional[builtins.str] = None,
-        event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
-        existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
-        existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
-        existing_fargate_service_object: typing.Optional[aws_cdk.aws_ecs.FargateService] = None,
-        existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+        event_bus_props: typing.Optional[typing.Union[_aws_cdk_aws_events_ceddda9d.EventBusProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        existing_container_definition_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ContainerDefinition] = None,
+        existing_event_bus_interface: typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus] = None,
+        existing_fargate_service_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.FargateService] = None,
+        existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
         fargate_service_props: typing.Any = None,
         fargate_task_definition_props: typing.Any = None,
-        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+        vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: -
         :param id: -
-        :param public_api: Whether the construct is deploying a private or public API. This has implications for the VPC deployed by this construct. Default: - None
+        :param public_api: Whether the construct is deploying a private or public API. This has implications for the VPC deployed by this construct.
         :param cluster_props: Optional properties to create a new ECS cluster. Default: - None
         :param container_definition_props: -
         :param ecr_image_version: The version of the image to use from the repository. Default: - 'latest'
@@ -198,27 +198,7 @@ class FargateToEventbridge(
         :param vpc_props: Optional custom properties for a VPC the construct will create. This VPC will be used by the new Fargate service the construct creates (that's why targetGroupProps can't include a VPC). Providing both this and existingVpc is an error. A Step Functions Interface endpoint will be included in this VPC. Default: - A set of defaults from vpc-defaults.ts: DefaultPublicPrivateVpcProps() for public APIs and DefaultIsolatedVpcProps() for private APIs.
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                public_api: builtins.bool,
-                cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
-                container_definition_props: typing.Any = None,
-                ecr_image_version: typing.Optional[builtins.str] = None,
-                ecr_repository_arn: typing.Optional[builtins.str] = None,
-                event_bus_environment_variable_name: typing.Optional[builtins.str] = None,
-                event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
-                existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
-                existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
-                existing_fargate_service_object: typing.Optional[aws_cdk.aws_ecs.FargateService] = None,
-                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-                fargate_service_props: typing.Any = None,
-                fargate_task_definition_props: typing.Any = None,
-                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__72360ca6199f323b560b4413b2989c561a5b401525d26b4599f1587a2a1093c4)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = FargateToEventbridgeProps(
@@ -242,23 +222,23 @@ class FargateToEventbridge(
 
     @builtins.property
     @jsii.member(jsii_name="container")
-    def container(self) -> aws_cdk.aws_ecs.ContainerDefinition:
-        return typing.cast(aws_cdk.aws_ecs.ContainerDefinition, jsii.get(self, "container"))
+    def container(self) -> _aws_cdk_aws_ecs_ceddda9d.ContainerDefinition:
+        return typing.cast(_aws_cdk_aws_ecs_ceddda9d.ContainerDefinition, jsii.get(self, "container"))
 
     @builtins.property
     @jsii.member(jsii_name="service")
-    def service(self) -> aws_cdk.aws_ecs.FargateService:
-        return typing.cast(aws_cdk.aws_ecs.FargateService, jsii.get(self, "service"))
+    def service(self) -> _aws_cdk_aws_ecs_ceddda9d.FargateService:
+        return typing.cast(_aws_cdk_aws_ecs_ceddda9d.FargateService, jsii.get(self, "service"))
 
     @builtins.property
     @jsii.member(jsii_name="vpc")
-    def vpc(self) -> aws_cdk.aws_ec2.IVpc:
-        return typing.cast(aws_cdk.aws_ec2.IVpc, jsii.get(self, "vpc"))
+    def vpc(self) -> _aws_cdk_aws_ec2_ceddda9d.IVpc:
+        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.IVpc, jsii.get(self, "vpc"))
 
     @builtins.property
     @jsii.member(jsii_name="eventBus")
-    def event_bus(self) -> typing.Optional[aws_cdk.aws_events.IEventBus]:
-        return typing.cast(typing.Optional[aws_cdk.aws_events.IEventBus], jsii.get(self, "eventBus"))
+    def event_bus(self) -> typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus], jsii.get(self, "eventBus"))
 
 
 @jsii.data_type(
@@ -286,22 +266,22 @@ class FargateToEventbridgeProps:
         self,
         *,
         public_api: builtins.bool,
-        cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
+        cluster_props: typing.Optional[typing.Union[_aws_cdk_aws_ecs_ceddda9d.ClusterProps, typing.Dict[builtins.str, typing.Any]]] = None,
         container_definition_props: typing.Any = None,
         ecr_image_version: typing.Optional[builtins.str] = None,
         ecr_repository_arn: typing.Optional[builtins.str] = None,
         event_bus_environment_variable_name: typing.Optional[builtins.str] = None,
-        event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
-        existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
-        existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
-        existing_fargate_service_object: typing.Optional[aws_cdk.aws_ecs.FargateService] = None,
-        existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+        event_bus_props: typing.Optional[typing.Union[_aws_cdk_aws_events_ceddda9d.EventBusProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        existing_container_definition_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ContainerDefinition] = None,
+        existing_event_bus_interface: typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus] = None,
+        existing_fargate_service_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.FargateService] = None,
+        existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
         fargate_service_props: typing.Any = None,
         fargate_task_definition_props: typing.Any = None,
-        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+        vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
-        :param public_api: Whether the construct is deploying a private or public API. This has implications for the VPC deployed by this construct. Default: - None
+        :param public_api: Whether the construct is deploying a private or public API. This has implications for the VPC deployed by this construct.
         :param cluster_props: Optional properties to create a new ECS cluster. Default: - None
         :param container_definition_props: -
         :param ecr_image_version: The version of the image to use from the repository. Default: - 'latest'
@@ -317,31 +297,13 @@ class FargateToEventbridgeProps:
         :param vpc_props: Optional custom properties for a VPC the construct will create. This VPC will be used by the new Fargate service the construct creates (that's why targetGroupProps can't include a VPC). Providing both this and existingVpc is an error. A Step Functions Interface endpoint will be included in this VPC. Default: - A set of defaults from vpc-defaults.ts: DefaultPublicPrivateVpcProps() for public APIs and DefaultIsolatedVpcProps() for private APIs.
         '''
         if isinstance(cluster_props, dict):
-            cluster_props = aws_cdk.aws_ecs.ClusterProps(**cluster_props)
+            cluster_props = _aws_cdk_aws_ecs_ceddda9d.ClusterProps(**cluster_props)
         if isinstance(event_bus_props, dict):
-            event_bus_props = aws_cdk.aws_events.EventBusProps(**event_bus_props)
+            event_bus_props = _aws_cdk_aws_events_ceddda9d.EventBusProps(**event_bus_props)
         if isinstance(vpc_props, dict):
-            vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
+            vpc_props = _aws_cdk_aws_ec2_ceddda9d.VpcProps(**vpc_props)
         if __debug__:
-            def stub(
-                *,
-                public_api: builtins.bool,
-                cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
-                container_definition_props: typing.Any = None,
-                ecr_image_version: typing.Optional[builtins.str] = None,
-                ecr_repository_arn: typing.Optional[builtins.str] = None,
-                event_bus_environment_variable_name: typing.Optional[builtins.str] = None,
-                event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
-                existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
-                existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
-                existing_fargate_service_object: typing.Optional[aws_cdk.aws_ecs.FargateService] = None,
-                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-                fargate_service_props: typing.Any = None,
-                fargate_task_definition_props: typing.Any = None,
-                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__5f853c823c1f28d7aa51af7ca286f586dffc1004b827da4d4cccabcb8d34ba4e)
             check_type(argname="argument public_api", value=public_api, expected_type=type_hints["public_api"])
             check_type(argname="argument cluster_props", value=cluster_props, expected_type=type_hints["cluster_props"])
             check_type(argname="argument container_definition_props", value=container_definition_props, expected_type=type_hints["container_definition_props"])
@@ -356,7 +318,7 @@ class FargateToEventbridgeProps:
             check_type(argname="argument fargate_service_props", value=fargate_service_props, expected_type=type_hints["fargate_service_props"])
             check_type(argname="argument fargate_task_definition_props", value=fargate_task_definition_props, expected_type=type_hints["fargate_task_definition_props"])
             check_type(argname="argument vpc_props", value=vpc_props, expected_type=type_hints["vpc_props"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "public_api": public_api,
         }
         if cluster_props is not None:
@@ -392,21 +354,19 @@ class FargateToEventbridgeProps:
 
         This has implications for the VPC deployed
         by this construct.
-
-        :default: - None
         '''
         result = self._values.get("public_api")
         assert result is not None, "Required property 'public_api' is missing"
         return typing.cast(builtins.bool, result)
 
     @builtins.property
-    def cluster_props(self) -> typing.Optional[aws_cdk.aws_ecs.ClusterProps]:
+    def cluster_props(self) -> typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ClusterProps]:
         '''Optional properties to create a new ECS cluster.
 
         :default: - None
         '''
         result = self._values.get("cluster_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_ecs.ClusterProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ClusterProps], result)
 
     @builtins.property
     def container_definition_props(self) -> typing.Any:
@@ -444,36 +404,38 @@ class FargateToEventbridgeProps:
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def event_bus_props(self) -> typing.Optional[aws_cdk.aws_events.EventBusProps]:
+    def event_bus_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_events_ceddda9d.EventBusProps]:
         '''A new custom EventBus is created with provided props.
 
         :default: - None
         '''
         result = self._values.get("event_bus_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_events.EventBusProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_events_ceddda9d.EventBusProps], result)
 
     @builtins.property
     def existing_container_definition_object(
         self,
-    ) -> typing.Optional[aws_cdk.aws_ecs.ContainerDefinition]:
+    ) -> typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ContainerDefinition]:
         result = self._values.get("existing_container_definition_object")
-        return typing.cast(typing.Optional[aws_cdk.aws_ecs.ContainerDefinition], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ContainerDefinition], result)
 
     @builtins.property
     def existing_event_bus_interface(
         self,
-    ) -> typing.Optional[aws_cdk.aws_events.IEventBus]:
+    ) -> typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus]:
         '''Existing instance of a custom EventBus.
 
         :default: - None
         '''
         result = self._values.get("existing_event_bus_interface")
-        return typing.cast(typing.Optional[aws_cdk.aws_events.IEventBus], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus], result)
 
     @builtins.property
     def existing_fargate_service_object(
         self,
-    ) -> typing.Optional[aws_cdk.aws_ecs.FargateService]:
+    ) -> typing.Optional[_aws_cdk_aws_ecs_ceddda9d.FargateService]:
         '''A Fargate Service already instantiated (probably by another Solutions Construct).
 
         If
@@ -485,10 +447,10 @@ class FargateToEventbridgeProps:
         :default: - None
         '''
         result = self._values.get("existing_fargate_service_object")
-        return typing.cast(typing.Optional[aws_cdk.aws_ecs.FargateService], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ecs_ceddda9d.FargateService], result)
 
     @builtins.property
-    def existing_vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
+    def existing_vpc(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc]:
         '''An existing VPC in which to deploy the construct.
 
         Providing both this and
@@ -499,7 +461,7 @@ class FargateToEventbridgeProps:
         :default: - None
         '''
         result = self._values.get("existing_vpc")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.IVpc], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc], result)
 
     @builtins.property
     def fargate_service_props(self) -> typing.Any:
@@ -516,7 +478,7 @@ class FargateToEventbridgeProps:
         return typing.cast(typing.Any, result)
 
     @builtins.property
-    def vpc_props(self) -> typing.Optional[aws_cdk.aws_ec2.VpcProps]:
+    def vpc_props(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.VpcProps]:
         '''Optional custom properties for a VPC the construct will create.
 
         This VPC will
@@ -531,7 +493,7 @@ class FargateToEventbridgeProps:
         and DefaultIsolatedVpcProps() for private APIs.
         '''
         result = self._values.get("vpc_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.VpcProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.VpcProps], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -551,3 +513,45 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__72360ca6199f323b560b4413b2989c561a5b401525d26b4599f1587a2a1093c4(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    public_api: builtins.bool,
+    cluster_props: typing.Optional[typing.Union[_aws_cdk_aws_ecs_ceddda9d.ClusterProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    container_definition_props: typing.Any = None,
+    ecr_image_version: typing.Optional[builtins.str] = None,
+    ecr_repository_arn: typing.Optional[builtins.str] = None,
+    event_bus_environment_variable_name: typing.Optional[builtins.str] = None,
+    event_bus_props: typing.Optional[typing.Union[_aws_cdk_aws_events_ceddda9d.EventBusProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    existing_container_definition_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ContainerDefinition] = None,
+    existing_event_bus_interface: typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus] = None,
+    existing_fargate_service_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.FargateService] = None,
+    existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+    fargate_service_props: typing.Any = None,
+    fargate_task_definition_props: typing.Any = None,
+    vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5f853c823c1f28d7aa51af7ca286f586dffc1004b827da4d4cccabcb8d34ba4e(
+    *,
+    public_api: builtins.bool,
+    cluster_props: typing.Optional[typing.Union[_aws_cdk_aws_ecs_ceddda9d.ClusterProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    container_definition_props: typing.Any = None,
+    ecr_image_version: typing.Optional[builtins.str] = None,
+    ecr_repository_arn: typing.Optional[builtins.str] = None,
+    event_bus_environment_variable_name: typing.Optional[builtins.str] = None,
+    event_bus_props: typing.Optional[typing.Union[_aws_cdk_aws_events_ceddda9d.EventBusProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    existing_container_definition_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ContainerDefinition] = None,
+    existing_event_bus_interface: typing.Optional[_aws_cdk_aws_events_ceddda9d.IEventBus] = None,
+    existing_fargate_service_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.FargateService] = None,
+    existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+    fargate_service_props: typing.Any = None,
+    fargate_task_definition_props: typing.Any = None,
+    vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
